@@ -1,6 +1,6 @@
 from flask_classful import FlaskView
 from notecoin.okex.strategy.domain import OkexCoin
-from notecoin.okex.strategy.utils import account_api
+from notecoin.okex.strategy.utils import account_api, market_api
 
 
 class Strategy1(FlaskView):
@@ -8,7 +8,7 @@ class Strategy1(FlaskView):
         self.usdt = 0
         self.coin_map = {}
 
-    def load(self):
+    def load_account(self):
         data = account_api.get_account().data[0]
         self.coin_map = {}
         for detail in data['details']:
@@ -19,6 +19,12 @@ class Strategy1(FlaskView):
             if coin.money > 1:
                 self.coin_map[coin.coin_id] = coin
 
+    def update_price(self):
+        data = market_api.get_tickers().data
+        data_map = dict([(cin['instId'], cin['last']) for cin in data])
+        for coin in self.coin_map.values():
+            coin.price = data_map[coin.coin_id]
+
     def to_json(self):
         return {
             "res": self.usdt,
@@ -26,7 +32,8 @@ class Strategy1(FlaskView):
         }
 
     def update(self):
-        self.load()
+        self.load_account()
+        self.update_price()
         for coin in self.coin_map.values():
             coin.watch()
         return self.to_json()
